@@ -1,9 +1,9 @@
-#' @param obj An \code{mdpolya_result} object.
+#' @param obj An `seqre_result` object.
 #' @param i A numeric vector of sample indices.
 #'
-#' @describeIn mdp Subset method for \code{mdpolya_result} objects
+#' @describeIn seqre Subset method for `seqre_result` objects
 #' @export
-`[[.mdpolya_result` <- function(obj, i) {
+`[[.seqreresult` <- function(obj, i) {
   if (!is.null(obj$theta)) {
     obj$theta <- obj$theta[i, , , drop = FALSE]
   }
@@ -12,21 +12,20 @@
   return(obj)
 }
 
-#' @param obj A \code{grideval_result} object.
-#' @param name The name of the attribute to access (i.e. \code{func},
-#'   \code{grid}, or \code{args}).
+#' @param obj A `grideval_result` object.
+#' @param name The name of the attribute to access (i.e. `func`, `grid`, or
+#'   `args`).
 #'
-#' @describeIn grideval Attribute access method for \code{grideval_result}
-#'   objects
+#' @describeIn grideval Attribute access method for `grideval_result` objects
 #' @export
 `$.grideval_result` <- function(obj, name) {
   attr(obj, name)
 }
 
-#' @param obj A \code{grideval_result} object.
+#' @param obj A `grideval_result` object.
 #' @param i A numeric vector of sample indices.
 #'
-#' @describeIn grideval Subset method for \code{grideval_result} objects
+#' @describeIn grideval Subset method for `grideval_result` objects
 #' @export
 `[[.grideval_result` <- function(obj, i) {
   out <- matrix(obj, dim(obj))[i, , drop = FALSE]
